package
Version:
v0.0.1
Opens a new window with list of versions in this module.
Published: Sep 26, 2022
License: MIT
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Options struct {
Count int
NoLowerCase bool
NoNumeric bool
NoSymbol bool
NoUpperCase bool
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.